NGPIris.parse_credentials package — NGPIris documentation

# NGPIris.parse_credentials package

## Submodules

## NGPIris.parse_credentials.parse_credentials module

class NGPIris.parse_credentials.parse_credentials.CredentialsHandler(credentials_path: str)

  Bases: `object`

NGPIris.parse_credentials.parse_credentials.all_fields_empty(key: str, credentials: dict[str, dict[str, str]]) → bool

NGPIris.parse_credentials.parse_credentials.check_empty_field(credentials: dict[str, dict[str, str]])

NGPIris.parse_credentials.parse_credentials.parse_credentials(credentials_path: str) → dict[str, dict[str, str]]

## Module contents